/***********************************************************************************************************************************
BZ2 Compress

Compress IO to the bz2 format.
***********************************************************************************************************************************/
#ifndef COMMON_COMPRESS_BZ2_COMPRESS_H
#define COMMON_COMPRESS_BZ2_COMPRESS_H

#include "common/io/filter/filter.h"

/***********************************************************************************************************************************
Filter type constant
***********************************************************************************************************************************/
#define BZ2_COMPRESS_FILTER_TYPE                                    STRID5("bz2-cmp", 0x41a3df3420)

/***********************************************************************************************************************************
Constructors
***********************************************************************************************************************************/
IoFilter *bz2CompressNew(int level);

#endif
